@@ -366,10 +366,11 @@ sub stream_append2 {
     my ($l1, $l2) = @_;
     weaken $_[0];
     weaken $_[1];
-    lazy {
+    lazyT {
         $l1 = force $l1;
         is_null($l1) ? $l2 : cons(car($l1), stream_append(cdr($l1), $l2))
     }
+    "FP::List::List"
 }
 
 sub stream_append {
@@ -388,9 +389,10 @@ sub stream_append {
         $ss->rest->fold(
             sub {
                 my ($s, $rest) = @_;
-                lazy {
+                lazyT {
                     stream_append2($s, $rest)
                 }
+                "FP::List::List"
             },
             $ss->first
         )
@@ -450,10 +452,11 @@ sub stream_map {
     @_ == 2 or fp_croak_arity 2;
     my ($fn, $l) = @_;
     weaken $_[1];
-    lazy {
+    lazyT {
         $l = force $l;
         is_null($l) ? null : cons(&$fn(car $l), stream_map($fn, cdr $l))
     }
+    "FP::List::List"
 }
 
 *FP::List::List::stream_map = flip \&stream_map;
@@ -462,12 +465,13 @@ sub stream_map_with_tail {
     @_ == 3 or fp_croak_arity 3;
     my ($fn, $l, $tail) = @_;
     weaken $_[1];
-    lazy {
+    lazyT {
         $l = force $l;
         is_null($l)
             ? $tail
             : cons(&$fn(car $l), stream_map_with_tail($fn, cdr($l), $tail))
     }
+    "FP::Abstract::Sequence"
 }
 
 *FP::List::List::stream_map_with_tail = flip2of3 \&stream_map_with_tail;
@@ -478,13 +482,14 @@ sub stream_zip2 {
     my ($l, $m) = @_;
     do { weaken $_ if is_promise $_ }
         for @_;    #needed?
-    lazy {
+    lazyT {
         $l = force $l;
         $m = force $m;
         (is_null $l or is_null $m)
             ? null
             : cons([car($l), car($m)], stream_zip2(cdr($l), cdr($m)))
     }
+    "FP::List::List"
 }
 
 *FP::List::List::stream_zip2 = \&stream_zip2;
@@ -494,7 +499,7 @@ sub stream_zip {
     my @ps = @_;
     do { weaken $_ if is_promise $_ }
         for @_;    #needed?
-    lazy {
+    lazyT {
         my @vs = map {
             my $v = force $_;
             is_null($v) ? return null : $v
@@ -503,6 +508,7 @@ sub stream_zip {
         my $b = stream_zip(map { cdr $_ } @vs);
         cons($a, $b)
     }
+    "FP::List::List"
 }
 
 *FP::List::List::stream_zip = \&stream_zip;    # XX fall back on zip2
@@ -512,12 +518,13 @@ sub stream_zip_with {
     my ($f, $l1, $l2) = @_;
     weaken $_[1];
     weaken $_[2];
-    lazy {
+    lazyT {
         my $l1 = force $l1;
         my $l2 = force $l2;
         (is_null $l1 or is_null $l2) ? null : cons &$f(car($l1), car($l2)),
             stream_zip_with($f, cdr($l1), cdr($l2))
     }
+    "FP::List::List"
 }
 
 *FP::List::List::stream_zip_with = flip2of3 \&stream_zip_with;
@@ -720,7 +727,7 @@ sub stream_take {
     @_ == 2 or fp_croak_arity 2;
     my ($s, $n) = @_;
     weaken $_[0];
-    lazy {
+    lazyT {
         if ($n > 0) {
             $s = force $s;
             is_null($s) ? $s : cons(car($s), stream_take(cdr($s), $n - 1));
@@ -728,6 +735,7 @@ sub stream_take {
             null
         }
     }
+    "FP::List::List"
 }
 
 *FP::List::List::stream_take = \&stream_take;
@@ -736,7 +744,7 @@ sub stream_take_while {
     @_ == 2 or fp_croak_arity 2;
     my ($fn, $s) = @_;
     weaken $_[1];
-    lazy {
+    lazyT {
         $s = force $s;
         if (is_null $s) {
             null
@@ -749,6 +757,7 @@ sub stream_take_while {
             }
         }
     }
+    "FP::List::List"
 }
 
 *FP::List::List::stream_take_while = flip \&stream_take_while;
@@ -764,7 +773,7 @@ sub stream_slice {
         my ($s) = @_;
         weaken $_[0];
         my $rec = $rec;
-        lazy {
+        lazyT {
             $s = force $s;
             if (is_null $s) {
                 $s    # null
@@ -776,6 +785,7 @@ sub stream_slice {
                 }
             }
         }
+        "FP::List::List"
     };
     @_ = ($start);
     goto &{ Weakened $rec};
@@ -789,7 +799,7 @@ sub stream_drop_while {
     @_ == 2 or fp_croak_arity 2;
     my ($pred, $s) = @_;
     weaken $_[1];
-    lazy {
+    lazyT {
     LP: {
             $s = force $s;
             if (!is_null $s and &$pred(car $s)) {
@@ -800,6 +810,7 @@ sub stream_drop_while {
             }
         }
     }
+    "FP::Abstract::Sequence"
 }
 
 *FP::List::List::stream_drop_while = flip \&stream_drop_while;
@@ -1115,7 +1126,7 @@ sub stream_cartesian_product_2 {
     $rec = sub {
         my ($a, $b) = @_;
         my $rec = $rec;
-        lazy {
+        lazyT {
             if (is_null $a) {
                 null
             } elsif (is_null $b) {
@@ -1124,6 +1135,7 @@ sub stream_cartesian_product_2 {
                 cons(cons(car($a), car($b)), &$rec($a, cdr $b))
             }
         }
+        "FP::List::List"
     };
     Weakened($rec)->($a, $orig_b)
 }
